PureBuilder<T> class
PureBuilder widget listens to changes in a Pure<T> or PureNode<T> state object or dynamically tracked states
and triggers targeted rebuilds.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PureBuilder
Constructors
-
PureBuilder({Key? key, PureNode<
T> ? pure, required Widget builder(BuildContext context, T value)}) -
Creates a PureBuilder listening to an explicit
puresignal or dynamic build context.const - PureBuilder.builder({Key? key, required Widget builder(BuildContext context)})
-
Creates a PureBuilder.builder with dynamic auto-tracking enabled.
const
Properties
- autoBuilder → Widget Function(BuildContext context)?
-
The auto-tracking builder closure function invoked when dynamic auto-tracking is active.
final
- builder → Widget Function(BuildContext context, T value)?
-
The builder closure function invoked when the signal updates.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
pure
→ PureNode<
T> ? -
The reactive node target to subscribe to explicitly.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PureBuilder< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited